<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:com="http://www.wipo.int/standards/XMLSchema/ST96/Common"
                xmlns:d="http://www.example.com/data"
                xmlns:fnx="http://www.example.com/fnx"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:m="http://www.w3.org/1998/Math/MathML3"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:tbl="http://www.oasis-open.org/tables/exchange/1.0"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
   <xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>
   <!--PHASES-->
   <!--PROLOG-->
   <xsl:output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
               method="xml"
               omit-xml-declaration="no"
               standalone="yes"
               indent="yes"/>
   <!--XSD TYPES FOR XSLT2-->
   <!--KEYS AND FUNCTIONS-->
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:is-exception"
                 as="xs:boolean">
      <xsl:param name="ruleID" as="xs:string"/>
      <xsl:param name="componentName" as="xs:string"/>
      <xsl:choose>
         <xsl:when test="($kWhereToApproveExceptions = 'InSchematronRules')">
            <xsl:choose>
               <xsl:when test="$isFlattened = false()">
                  <xsl:value-of select="$approvedExceptions and boolean($approvedExceptions/ApprovedExceptions/ApprovedException[@ruleID=$ruleID]/xsd[not(@subdir) or @subdir=$inSubdirName][@file=$localFile])"/>
               </xsl:when>
               <xsl:otherwise>
                  <xsl:variable name="ns"
                                select="                 if (contains($componentName, ':')) then                   ($namespaces[@ns-prefix = substring-before($componentName, ':')]/@subdir)                 else                   ($targetNamespaceName)"/>
                  <xsl:message>
                     <xsl:value-of select="$ruleID"/>: check if <xsl:value-of select="$componentName"/> is in list of exceptions (<xsl:value-of select="string-join($approvedExceptions/ApprovedExceptions/ApprovedException[@ruleID = $ruleID]/xsd[not(@subdir) or @subdir = $ns]/@file/replace(., '(.+/)?([A-Za-z][^\.]+)\.xsd', '$2'), ', ')"/>) </xsl:message>
                  <xsl:value-of select="$approvedExceptions and ($approvedExceptions/ApprovedExceptions/ApprovedException[@ruleID = $ruleID]/xsd[not(@subdir) or @subdir = $ns]/@file/replace(., '(.+/)?([A-Za-z][^\.]+)\.xsd', '$2') = $componentName)"/>
               </xsl:otherwise>
            </xsl:choose>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="false()"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:ipo-ns"
                 as="xs:string?">
      <xsl:param name="area" as="xs:string"/>
      <xsl:param name="part" as="xs:string"/>
      <xsl:value-of select="$namespaces[not(@std ='external' or @std = 'ST96')][@component = $area]/@*[name() = $part]"/>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:xsdVersionFromFileName"
                 as="xs:string?">
      <xsl:param name="fname" as="xs:string"/>
      <xsl:analyze-string select="$fname"
                          regex="^[a-zA-Z0-9]+_(V[0-9]+_[0-9]+)_D([0-9]+)\.[a-zA-Z0-9]+$">
         <xsl:matching-substring>
            <xsl:value-of select="regex-group(1)"/>
         </xsl:matching-substring>
      </xsl:analyze-string>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:buildPrefixTable"
                 as="element()">
      <xsl:param name="root" as="node()"/>
      <d:prefixBindings>
         <xsl:for-each select="$root/namespace::*">
            <d:prefixBinding nsPrefix="{name()}" nsName="{.}"/>
         </xsl:for-each>
      </d:prefixBindings>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:buildLookupTable"
                 as="element()">
      <d:lookUp>
         <xsl:for-each select="distinct-values($definitions//d:namespace/@ns)">
            <xsl:variable name="ns" select="."/>
            <d:entry ns="{.}">
               <xsl:for-each-group select="$definitions//d:namespace[@ns = $ns]/*[local-name() != 'namespace']"
                                   group-by="@name">
                  <xsl:copy-of select="current-group()[1]"/>
               </xsl:for-each-group>
            </d:entry>
         </xsl:for-each>
      </d:lookUp>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:gatherDefinitionsRoot"
                 as="element()*">
      <xsl:param name="schemaRoot" as="node()"/>
      <xsl:param name="depth" as="xsd:integer"/>
      <d:defs>
         <xsl:sequence select="fnx:gatherDefinitions($schemaRoot, 0)"/>
      </d:defs>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:gatherDefinitions"
                 as="element()*">
      <xsl:param name="schemaRoot" as="node()?"/>
      <xsl:param name="depth" as="xsd:integer"/>
      <xsl:if test="$depth &lt; 5">
         <xsl:variable name="nsName"
                       select="if ($schemaRoot/@targetNamespace) then $schemaRoot/@targetNamespace else 'DEFAULT'"/>
         <d:namespace ns="{$nsName}">
            <xsl:for-each select="$schemaRoot/(xsd:include|xsd:import)">
               <xsl:sequence select="fnx:gatherDefinitions(document(@schemaLocation)/xsd:schema, $depth + 1)"/>
            </xsl:for-each>
            <xsl:sequence select="$schemaRoot/(xsd:element|xsd:attribute|xsd:complexType|xsd:simpleType)"/>
         </d:namespace>
      </xsl:if>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:same-position-LC"
                 as="xs:boolean">
      <xsl:param name="str" as="xs:string"/>
      <xsl:param name="substr" as="xs:string"/>
      <xsl:variable name="strLC" select="lower-case($str)"/>
      <xsl:variable name="substrLC" select="lower-case($substr)"/>
      <xsl:value-of select="contains($str, $substr)                           and lower-case(substring-after($str, $substr))                             = substring-after($strLC, $substrLC)"/>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:find-improper-embedded-abbreviation-rest"
                 as="xs:string*">
      <xsl:param name="nameRest" as="xs:string"/>
      <xsl:param name="abbrev" as="xs:string"/>
      <xsl:if test="$nameRest != ''">
         <xsl:variable name="nameRestLC" select="lower-case($nameRest)"/>
         <xsl:variable name="abbrevLC" select="lower-case($abbrev)"/>
         <xsl:if test="contains($nameRestLC, $abbrevLC)">
            <xsl:choose>
               <xsl:when test="not(fnx:same-position-LC($nameRest, $abbrev))">
                  <xsl:value-of select="$abbrev"/>
               </xsl:when>
               <xsl:otherwise>
                  <xsl:variable name="rest" select="substring-after($nameRest, $abbrev)"/>
                  <xsl:value-of select="fnx:find-improper-embedded-abbreviation-rest($rest, $abbrev)"/>
               </xsl:otherwise>
            </xsl:choose>
         </xsl:if>
      </xsl:if>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:find-improper-embedded-abbreviation-in-attribute"
                 as="xs:string*">
      <xsl:param name="attrName" as="xs:string"/>
      <xsl:variable name="attrNameLC" select="lower-case($attrName)"/>
      <xsl:for-each select="$approvedAcronyms/AAs/AA/short[string-length() &gt; 2]">
         <xsl:variable name="abbrev" select="."/>
         <xsl:variable name="abbrevLC" select="lower-case($abbrev)"/>
         <xsl:choose>
            <xsl:when test="starts-with($attrNameLC, $abbrevLC) and not(starts-with($attrName, $abbrevLC))">
               <xsl:value-of select="$abbrev"/>
            </xsl:when>
            <xsl:when test="starts-with($attrNameLC, $abbrevLC) and starts-with($attrName, $abbrevLC)">
               <xsl:value-of select="fnx:find-improper-embedded-abbreviation-rest(substring-after($attrName, $abbrevLC), $abbrev)"/>
            </xsl:when>
            <xsl:otherwise>
               <xsl:value-of select="fnx:find-improper-embedded-abbreviation-rest($attrName, $abbrev)"/>
            </xsl:otherwise>
         </xsl:choose>
      </xsl:for-each>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:find-improper-embedded-abbreviation-in-element-or-type"
                 as="xs:string*">
      <xsl:param name="elName" as="xs:string"/>
      <xsl:for-each select="$approvedAcronyms/AAs/AA/short[string-length() &gt; 2]">
         <xsl:variable name="abbrev" select="."/>
         <xsl:value-of select="fnx:find-improper-embedded-abbreviation-rest($elName, $abbrev)"/>
      </xsl:for-each>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:words-from-name"
                 as="xs:string*">
      <xsl:param name="name"/>
      <xsl:sequence select="tokenize(replace(replace($name,'([A-Z]*)([A-Z][^A-Z]+)',' $2'),'[A-Z]+$',''),' ')"/>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:getRepTerm"
                 as="xs:string">
      <xsl:param name="name" as="xs:string"/>
      <xsl:choose>
         <xsl:when test="ends-with($name, 'DateTime')">DateTime</xsl:when>
         <xsl:when test="ends-with($name, 'Time')">Time</xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="string-join(                             (for $repTerm in $kRepresentationTerms                              return                                if (ends-with(lower-case($name),                                              lower-case($repTerm))                                    or                                    ends-with(lower-case($name),                                              lower-case(concat($repTerm, 'Type')))                                   )                                then $repTerm                                else ''),                                '')"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:allowedRepTerms"
                 as="xsd:string*">
      <xsl:param name="n" as="node()"/>
      <xsl:variable name="result" as="xsd:string*">
         <xsl:choose>
            <xsl:when test="not($n)">
               <xsl:value-of select="()"/>
            </xsl:when>
            <xsl:when test="((local-name($n) = 'element') or (local-name($n) = 'attribute')) and not($n/@type)">
               <xsl:value-of select="('Text', 'Name', 'Number')"/>
            </xsl:when>
            <xsl:when test="$n/xsd:union">
               <xsl:value-of select="('Category', 'Code', 'Identifier', 'Number')"/>
            </xsl:when>
            <xsl:when test="$n/@type or $n/xsd:restriction or $n/xsd:simpleContent/*/@base or $n/*/@base">
               <xsl:variable name="basicType"
                             select="($n/@type, $n/xsd:restriction/@base, $n/xsd:simpleContent/*/@base, $n/*/@base)[1]"/>
               <xsl:choose>
                  <xsl:when test="$basicType = 'com:AmountType'">
                     <xsl:value-of select="('Amount')"/>
                  </xsl:when>
                  <xsl:when test="$basicType = 'xsd:token'">
                     <xsl:value-of select="('Category', 'Code', 'Identifier', 'Number', 'Text', 'Name')"/>
                  </xsl:when>
                  <xsl:when test="$basicType = 'xsd:boolean'">
                     <xsl:value-of select="('Indicator')"/>
                  </xsl:when>
                  <xsl:when test="($basicType = 'com:DateType') or ($basicType = 'xsd:date')">
                     <xsl:value-of select="('Date')"/>
                  </xsl:when>
                  <xsl:when test="$basicType = 'com:MeasureType'">
                     <xsl:value-of select="('Measure')"/>
                  </xsl:when>
                  <xsl:when test="($basicType = 'xsd:positiveInteger')">
                     <xsl:value-of select="('Number')"/>
                  </xsl:when>
                  <xsl:when test="($basicType = 'com:QuantityType') or ($basicType = 'xsd:nonNegativeInteger')">
                     <xsl:value-of select="('Quantity')"/>
                  </xsl:when>
                  <xsl:when test="($basicType = 'xsd:decimal')">
                     <xsl:value-of select="('Percent', 'Rate', 'Quantity')"/>
                  </xsl:when>
                  <xsl:when test="$basicType = 'xsd:string'">
                     <xsl:value-of select="('Text', 'Name', 'Number', 'Identifier', 'Category')"/>
                  </xsl:when>
                  <xsl:when test="($basicType = 'xsd:time')">
                     <xsl:value-of select="('Time')"/>
                  </xsl:when>
                  <xsl:when test="($basicType = 'xsd:dateTime')">
                     <xsl:value-of select="('DateTime')"/>
                  </xsl:when>
                  <xsl:when test="($basicType = 'xsd:anyURI')">
                     <xsl:value-of select="('URI')"/>
                  </xsl:when>
                  <xsl:when test="($basicType = 'xsd:anySimpleType')                             or ($basicType = 'xsd:ID')                             or ($basicType = 'xsd:IDREF')                             or ($basicType = 'xsd:IDREFS')                             ">
                     <xsl:value-of select="('EXEMPT')"/>
                  </xsl:when>
                  <xsl:when test="$n/xsd:simpleContent/*/@base">
                     <xsl:value-of select="fnx:allowedRepTerms(fnx:get-xsd-definition(root($n), $basicType))"/>
                  </xsl:when>
                  <xsl:when test="$n/@type">
                     <xsl:value-of select="fnx:allowedRepTerms(fnx:get-xsd-definition(root($n), $n/@type))"/>
                  </xsl:when>
                  <xsl:when test="$n/xsd:restriction/xsd:enumeration">
                     <xsl:value-of select="('Category', 'Code')"/>
                  </xsl:when>
                  <xsl:otherwise>
              
              ()
            </xsl:otherwise>
               </xsl:choose>
            </xsl:when>
            <xsl:otherwise>()</xsl:otherwise>
         </xsl:choose>
      </xsl:variable>
      <xsl:value-of select="$result"/>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:usesAllowedRepTerm"
                 as="xsd:boolean">
      <xsl:param name="repTerm" as="xs:string"/>
      <xsl:param name="allowedRepTerms" as="xs:string?"/>
      <xsl:sequence select="contains(concat(' ', $allowedRepTerms, ' '), concat(' ', $repTerm, ' '))"/>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:isBasicComponent"
                 as="xsd:boolean">
      <xsl:param name="n" as="node()"/>
      <xsl:variable name="result">
         <xsl:choose>
            <xsl:when test="not((local-name($n) = 'element') or (local-name($n) = 'attribute'))">
               <xsl:value-of select="false()"/>
            </xsl:when>
            <xsl:when test="not($n)">
               <xsl:value-of select="false()"/>
            </xsl:when>
            <xsl:when test="not($n/@type) and $n/*">
               <xsl:message>WARNING: <xsd:value-of select="$n/@name"/>:  XSD styles with nested type definitions are not currently supported.</xsl:message>
               <xsl:value-of select="false()"/>
            </xsl:when>
            <xsl:when test="not($n/@type)">
               <xsl:value-of select="true()"/>
            </xsl:when>
            <xsl:when test="   $n/@type = 'com:AmountType'                         or $n/@type = 'xsd:token'                         or $n/@type = 'com:DateType'                         or $n/@type = 'xsd:date'                         or $n/@type = 'xsd:token'                         or $n/@type = 'xsd:boolean'                         or $n/@type = 'com:MeasureType'                         or $n/@type = 'xsd:string'                         or $n/@type = 'xsd:positiveInteger'                         or $n/@type = 'xsd:decimal'                         or $n/@type = 'com:QuantityType'                         or $n/@type = 'xsd:nonNegativeInteger'                         or $n/@type = 'xsd:time'                         or $n/@type = 'xsd:dateTime'                         or $n/@type = 'xsd:anyURI'                         ">
               <xsl:value-of select="true()"/>
            </xsl:when>
            <xsl:otherwise>
               <xsl:variable name="typeDef" select="fnx:get-xsd-definition(root($n), $n/@type)"/>
               <xsl:choose>
                  <xsl:when test="$typeDef/xsd:simpleContent">
                     <xsl:value-of select="true()"/>
                  </xsl:when>
                  <xsl:when test="local-name($typeDef) = 'simpleType'">
                     <xsl:value-of select="true()"/>
                  </xsl:when>
                  <xsl:otherwise>
                     <xsl:value-of select="false()"/>
                  </xsl:otherwise>
               </xsl:choose>
            </xsl:otherwise>
         </xsl:choose>
      </xsl:variable>
      <xsl:value-of select="$result"/>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:makeCommaList"
                 as="xsd:string">
      <xsl:param name="sList" as="xs:string*"/>
      <xsl:param name="orOrAnd" as="xs:string"/>
      <xsl:variable name="commaList" as="xs:string*">
         <xsl:for-each select="$sList">
            <xsl:choose>
               <xsl:when test="position() = 1">
                  <xsl:value-of select="."/>
               </xsl:when>
               <xsl:when test="position() = last() and position() != 1">
                  <xsl:text> </xsl:text>
                  <xsl:value-of select="$orOrAnd"/>
                  <xsl:text> </xsl:text>
                  <xsl:value-of select="."/>
               </xsl:when>
               <xsl:otherwise>
                  <xsl:text>, </xsl:text>
                  <xsl:value-of select="."/>
               </xsl:otherwise>
            </xsl:choose>
         </xsl:for-each>
      </xsl:variable>
      <xsl:value-of select="string-join($commaList, '')"/>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:isTableRelated"
                 as="xs:boolean">
      <xsl:param name="name" as="xs:string?"/>
      <xsl:sequence select="$name                           and fnx:contains-i($name, 'table')                           and not(ends-with($name,'Indicator'))                           and not(matches($name, 'tablebody', 'i'))                           and not(matches($name, 'tablegroup', 'i'))                           and not(matches($name, 'tableimage', 'i'))                           and not(matches($name, 'tabletitle', 'i'))                           and not(matches($name, 'tabledata', 'i'))                           and not(matches($name, 'tablecell', 'i'))                           and not(matches($name, 'tabledatacell', 'i'))                           and not(matches($name, 'tablefooter', 'i'))                           and not(matches($name, 'tablehead', 'i'))                           and not(matches($name, 'tableheadercell', 'i'))                           and not(matches($name, 'tablerow', 'i'))                           "/>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:hasCorrectMixOfUnboundedChildrenToBeACollection"
                 as="xs:boolean">
      <xsl:param name="complexType" as="element()?"/>
      <xsl:sequence select="exists($complexType)                           and                           (exists($complexType/xsd:choice[@maxOccurs = 'unbounded'])                            or                            exists($complexType/xsd:choice[not(@maxOccurs = 'unbounded') and not(xsd:element[not(@maxOccurs = 'unbounded')][1] or xsd:sequence or xsd:choice)]/xsd:element[@maxOccurs = 'unbounded'])                            or                            exists($complexType/xsd:sequence[not(@maxOccurs = 'unbounded') and not(xsd:element[not(@maxOccurs = 'unbounded')][1] or xsd:sequence or xsd:choice)]/xsd:element[@maxOccurs = 'unbounded'])                            or                            exists($complexType/*[local-name() ne 'sequence' and local-name() ne 'choice']/xsd:choice[@maxOccurs = 'unbounded'])                           )"/>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:isACollection"
                 as="xs:boolean">
      <xsl:param name="e" as="element()?"/>
      <xsl:variable name="eIsACollection" as="xs:boolean">
         <xsl:choose>
            <xsl:when test="not($e)">
               <xsl:value-of select="false()"/>
            </xsl:when>
            <xsl:when test="$e/@mixed = 'true'">
               <xsl:value-of select="false()"/>
            </xsl:when>
            <xsl:when test="local-name($e) = 'element'">
               <xsl:value-of select="    fnx:hasCorrectMixOfUnboundedChildrenToBeACollection($e/xsd:complexType)                                 or ($e/@type and fnx:isACollection(fnx:get-xsd-definition(root($e), $e/@type)))"/>
            </xsl:when>
            <xsl:when test="local-name($e) = 'complexType'">
               <xsl:value-of select="fnx:hasCorrectMixOfUnboundedChildrenToBeACollection($e)"/>
            </xsl:when>
            <xsl:otherwise>
               <xsl:value-of select="false()"/>
            </xsl:otherwise>
         </xsl:choose>
      </xsl:variable>
      <xsl:value-of select="$eIsACollection"/>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:hasAnEnumerationList"
                 as="xs:boolean">
      <xsl:param name="elem" as="element()?"/>
      <xsl:choose>
         <xsl:when test="$elem/self::xsd:simpleType/xsd:restriction/xsd:enumeration">
            <xsl:value-of select="true()"/>
         </xsl:when>
         <xsl:when test="$elem/self::xsd:simpleType/xsd:restriction/xsd:pattern">
            <xsl:value-of select="false()"/>
         </xsl:when>
         <xsl:when test="$elem/self::xsd:element/@type[namespace-uri-from-QName(resolve-QName(., $elem)) eq $kXMLSchemaNamespace]">
            <xsl:value-of select="false()"/>
         </xsl:when>
         <xsl:when test="$elem/self::xsd:element[@type]">
            <xsl:value-of select="             some $x in $elem/@type,               $ns in namespace-uri-from-QName(resolve-QName($x, $elem))             satisfies               (fnx:hasAnEnumerationList($lookupTable/d:entry[@ns eq $ns]/*[@name eq replace($x,'^.+:','')]))"/>
         </xsl:when>
         <xsl:when test="$elem/self::xsd:attribute/@type[namespace-uri-from-QName(resolve-QName(., $elem)) eq $kXMLSchemaNamespace]">
            <xsl:value-of select="false()"/>
         </xsl:when>
         <xsl:when test="$elem/self::xsd:attribute[@type]">
            <xsl:value-of select="             some $x in $elem/@type,               $ns in namespace-uri-from-QName(resolve-QName($x, $elem))             satisfies               (fnx:hasAnEnumerationList($lookupTable/d:entry[@ns eq $ns]/*[@name eq replace($x,'^.+:','')]))"/>
         </xsl:when>
         <xsl:when test="$elem/self::xsd:simpleType/xsd:union">
            <xsl:value-of select="             some $x in tokenize(normalize-space($elem/xsd:union/@memberTypes), ' '),               $ns in namespace-uri-from-QName(resolve-QName($x, $elem))               satisfies (for $m in $lookupTable/d:entry[@ns eq $ns]/*[@name eq replace($x, '^.+:','')]               return                 (fnx:hasAnEnumerationList($m)))"/>
         </xsl:when>
         <xsl:when test="$elem/self::xsd:complexType/xsd:simpleContent/xsd:extension/@base">
            <xsl:value-of select="             some $x in $elem/self::xsd:complexType/xsd:simpleContent/xsd:extension/@base,               $ns in namespace-uri-from-QName(resolve-QName($x, $elem))             satisfies               (fnx:hasAnEnumerationList($lookupTable/d:entry[@ns eq $ns]/*[@name eq replace($x,'^.+:','')]))"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="false()"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:splitCamelCase"
                 as="xsd:string*">
      <xsl:param name="componentName" as="xsd:string"/>
      <xsl:variable name="split">
         <xsl:value-of select="replace(replace(replace($componentName, '([a-z0-9]*)([A-Z0-9]{2,})?([A-Z0-9]([a-z]))','$1 $2 $3'), '([a-z0-9])([A-Z][A-Z0-9]*)','$1 $2'), '_(V\d+_\d+)',' _$1')"/>
      </xsl:variable>
      <xsl:sequence select="tokenize($split,'[\s]+')[matches(.,'\w')]"/>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:splitEnumeration"
                 as="xsd:string*">
      <xsl:param name="enumerationValue" as="xsd:string"/>
      <xsl:variable name="split">
         <xsl:value-of select="replace(replace($enumerationValue,'([a-z0-9]*)([A-Z0-9]{2,})?([A-Z0-9]([a-z]))','$1 $2 $3'),'([a-z0-9])([A-Z][A-Z0-9]+)','$1 $2')"/>
      </xsl:variable>
      <xsl:sequence select="tokenize(translate($split,'_',' '), '[\s]+')[matches(., '\w')]"/>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:getNSPrefix"
                 as="xs:string">
      <xsl:param name="n" as="node()"/>
      <xsl:param name="nsName" as="xs:string"/>
      <xsl:variable name="nsNode" select="$n/namespace::node()[.=$nsName]"/>
      <xsl:value-of select="local-name($nsNode)"/>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:assertSpecificNSPrefix"
                 as="xs:string?">
      <xsl:param name="n" as="node()"/>
      <xsl:param name="nsName" as="xs:string"/>
      <xsl:param name="shouldBePrefix" as="xs:string"/>
      <xsl:variable name="prefix" select="fnx:getNSPrefix($n, $nsName)"/>
      <xsl:choose>
         <xsl:when test="$prefix = '' or $prefix = $shouldBePrefix">
            <xsl:sequence select="()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="concat($shouldBePrefix, ': prefix (not ', $prefix, ':) must be used for the ', $nsName, ' namespace.')"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:assertAnyNSPrefix"
                 as="xs:string">
      <xsl:param name="n" as="node()"/>
      <xsl:param name="nsName" as="xs:string"/>
      <xsl:variable name="prefix" select="fnx:getNSPrefix($n, $nsName)"/>
      <xsl:choose>
         <xsl:when test="$prefix = ''">
            <xsl:value-of select="concat('A namespace prefix must be used for the ', $nsName, ' namespace.')"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="''"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:contains-i"
                 as="xs:boolean">
      <xsl:param name="s" as="xs:string"/>
      <xsl:param name="subs" as="xs:string"/>
      <xsl:sequence select="contains(lower-case($s), lower-case($subs))"/>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:find-i"
                 as="xs:boolean">
      <xsl:param name="s" as="xs:string"/>
      <xsl:param name="subs" as="xs:string"/>
      <xsl:sequence select="contains(lower-case($s), lower-case($subs))"/>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:get-xsd-definition"
                 as="node()?">
      <xsl:param name="schemaRoot" as="node()"/>
      <xsl:param name="typeName" as="xsd:string"/>
      <xsl:variable name="typeNameNoPrefix"
                    select="if (contains($typeName, ':')) then substring-after($typeName, ':') else $typeName"/>
      <xsl:variable name="nsPrefix"
                    as="xsd:string"
                    select="substring-before($typeName, ':')"/>
      <xsl:variable name="nsName" as="xsd:string">
         <xsl:choose>
            <xsl:when test="$nsPrefix = '' and $schemaRoot/xsd:schema/@targetNamespace">
               <xsl:value-of select="$schemaRoot/xsd:schema/@targetNamespace"/>
            </xsl:when>
            <xsl:when test="$nsPrefix = 'com'">
               <xsl:value-of select="$kCommonNamespace"/>
            </xsl:when>
            <xsl:when test="$nsPrefix = ''">
               <xsl:value-of select="'DEFAULT'"/>
            </xsl:when>
            <xsl:otherwise>
               <xsl:value-of select="$prefixTable/d:prefixBinding[@nsPrefix = $nsPrefix]/@nsName"/>
            </xsl:otherwise>
         </xsl:choose>
      </xsl:variable>
      <xsl:variable name="result"
                    select="$lookupTable/d:entry[@ns=$nsName]/*[@name=$typeNameNoPrefix][1]"/>
      <xsl:sequence select="$result"/>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:starts-with-ST3-code"
                 as="xsd:boolean">
      <xsl:param name="s" as="xsd:string"/>
      <xsl:sequence select="exists(index-of($st3Codes,substring($s,1,2)))"/>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:has-fixed-attribute"
                 as="xsd:boolean">
      <xsl:param name="el" as="element()"/>
      <xsl:param name="attName" as="xsd:string"/>
      <xsl:param name="use" as="xsd:string"/>
      <xsl:param name="fixedRegex" as="xsd:string"/>
      <xsl:variable name="def" select="fnx:get-xsd-definition(root($el), $el/@type)"/>
      <xsl:variable name="attdef1"
                    select="fnx:get-attributes-from-type-recursive($def,$attName)"/>
      <xsl:variable name="attdef2"
                    select="if ($attdef1/@name) then $attdef1 else fnx:get-xsd-definition(root($el), $attdef1/@ref)"/>
      <xsl:value-of select="boolean($attdef1[@use=$use or (not(@use) and $use = 'optional')] and ($attdef1|$attdef2)[matches(@fixed, $fixedRegex)])"/>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:has-attribute"
                 as="xsd:boolean">
      <xsl:param name="el" as="element()"/>
      <xsl:param name="attName" as="xsd:string"/>
      <xsl:param name="use" as="xsd:string"/>
      <xsl:variable name="def" select="fnx:get-xsd-definition(root($el), $el/@type)"/>
      <xsl:variable name="attdef1"
                    select="fnx:get-attributes-from-type-recursive($def,$attName)"/>
      <xsl:message>
          checking <xsl:value-of select="concat($attName, ' ', $use)"/>
      </xsl:message>
      <xsl:variable name="attdef2"
                    select="if ($attdef1/@name) then $attdef1 else fnx:get-xsd-definition(root($el), $attdef1/@ref)"/>
      <xsl:value-of select="boolean($attdef1[@use=$use or (not(@use) and $use = 'optional')])"/>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:get-attributes-from-type-recursive"
                 as="element()*">
      <xsl:param name="ty" as="element()?"/>
      <xsl:param name="attName" as="xsd:string"/>
      <xsl:variable name="local-def"
                    select="$ty//xsd:attribute[(@name=$attName or ends-with(@ref,$attName))]"/>
      <xsl:choose>
         <xsl:when test="$local-def">
            <xsl:sequence select="$local-def"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:variable name="extension"
                          select="$ty/(xsd:complexContent|xsd:simpleContent)/xsd:extension"/>
            <xsl:choose>
               <xsl:when test="$extension">
                  <xsl:variable name="base-def-ext"
                                select="fnx:get-xsd-definition(root($ty), $extension/@base)"/>
                  <xsl:sequence select="fnx:get-attributes-from-type-recursive($base-def-ext,$attName)"/>
               </xsl:when>
               <xsl:otherwise>
                  <xsl:variable name="restriction"
                                select="$ty/(xsd:complexContent|xsd:simpleContent)/xsd:restriction"/>
                  <xsl:if test="$restriction">
                     <xsl:variable name="base-def-res"
                                   select="fnx:get-xsd-definition(root($ty), $restriction/@base)"/>
                     <xsl:sequence select="fnx:get-attributes-from-type-recursive($base-def-res,$attName)"/>
                  </xsl:if>
               </xsl:otherwise>
            </xsl:choose>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:uses-type"
                 as="xsd:boolean">
      <xsl:param name="n" as="node()?"/>
      <xsl:param name="usesTypeName" as="xsd:string"/>
      <xsl:param name="depth" as="xsd:integer"/>
      <xsl:choose>
         <xsl:when test="$depth &lt; 7">
            <xsl:variable name="result">
               <xsl:choose>
                  <xsl:when test="empty($n)">
                     <xsl:value-of select="false()"/>
                  </xsl:when>
                  <xsl:when test="local-name($n) = 'extension'">
                     <xsl:value-of select="$n/@base = $usesTypeName                                     or                                     fnx:uses-type(fnx:get-xsd-definition(root($n), $n/@base), $usesTypeName, $depth+1)                                     or                                     fnx:uses-type($n/*[1], $usesTypeName, $depth+1)                                     "/>
                  </xsl:when>
                  <xsl:when test="local-name($n) = 'element'">
                     <xsl:choose>
                        <xsl:when test="$n/@type and $n[@type = $usesTypeName]">
                           <xsl:value-of select="true()"/>
                        </xsl:when>
                        <xsl:when test="$n/@type">
                           <xsl:value-of select="fnx:uses-type(fnx:get-xsd-definition(root($n), $n/@type), $usesTypeName, $depth+1)"/>
                        </xsl:when>
                        <xsl:when test="$n/@ref and $n[@ref = $usesTypeName]">
                           <xsl:value-of select="true()"/>
                        </xsl:when>
                        <xsl:when test="$n/@ref">
                           <xsl:value-of select="fnx:uses-type(fnx:get-xsd-definition(root($n), $n/@ref), $usesTypeName, $depth+1)"/>
                        </xsl:when>
                        <xsl:otherwise>
                           <xsl:value-of select="false()"/>
                        </xsl:otherwise>
                     </xsl:choose>
                  </xsl:when>
                  <xsl:when test="local-name($n) = 'attribute'">
                     <xsl:value-of select="false()"/>
                  </xsl:when>
                  <xsl:when test="local-name($n) = 'complexType'">
                     <xsl:choose>
                        <xsl:when test="$n/@name = $usesTypeName">
                           <xsl:value-of select="true()"/>
                        </xsl:when>
                        <xsl:when test="some $child in $n//(xsd:element|xsd:extension) satisfies fnx:uses-type($child, $usesTypeName, $depth+1)">
                           <xsl:value-of select="true()"/>
                        </xsl:when>
                        <xsl:otherwise>
                           <xsl:value-of select="false()"/>
                        </xsl:otherwise>
                     </xsl:choose>
                  </xsl:when>
                  <xsl:when test="local-name($n) = 'simpleType'">
                     <xsl:choose>
                        <xsl:when test="$n/xsd:union">
                           <xsl:value-of select="contains($n/xsd:union/@memberTypes, $usesTypeName)"/>
                        </xsl:when>
                        <xsl:otherwise>
                           <xsl:value-of select="false()"/>
                        </xsl:otherwise>
                     </xsl:choose>
                  </xsl:when>
                  <xsl:otherwise>
                     <xsl:value-of select="false()"/>
                  </xsl:otherwise>
               </xsl:choose>
            </xsl:variable>
            <xsl:value-of select="$result"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="false()"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 xmlns:mathml="http://www.w3.org/1998/Math/MathML3"
                 xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                 name="fnx:isURI"
                 as="xs:boolean">
      <xsl:param name="targetNamespace" as="xs:string?"/>
      <xsl:sequence select="$targetNamespace and                           (starts-with($targetNamespace, 'http:')                           or starts-with($targetNamespace, 'https:')                           or starts-with($targetNamespace, 'urn:'))                           "/>
   </xsl:function>
   <!--DEFAULT RULES-->
   <!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-2-->
   <!--This mode can be used to generate prefixed XPath for humans-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
   <!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: GENERATE-ID-FROM-PATH -->
   <xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>
   <!--MODE: GENERATE-ID-2 -->
   <xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters-->
   <xsl:template match="text()" priority="-1"/>
   <!--SCHEMA SETUP-->
   <xsl:template match="/">
      <svrl:schematron-output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                              title="WIPO ST.96 Conformance Validation"
                              schemaVersion="1.0">
         <xsl:comment>
            <xsl:value-of select="$archiveDirParameter"/>   
		 <xsl:value-of select="$archiveNameParameter"/>  
		 <xsl:value-of select="$fileNameParameter"/>  
		 <xsl:value-of select="$fileDirParameter"/>
         </xsl:comment>
         <svrl:ns-prefix-in-attribute-values uri="http://www.example.com/fnx" prefix="fnx"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.example.com/data" prefix="d"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/1998/Math/MathML3" prefix="m"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.oasis-open.org/tables/exchange/1.0" prefix="tbl"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.wipo.int/standards/XMLSchema/ST96/Common" prefix="com"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema" prefix="xsd"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="name">SD-63</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M83"/>
      </svrl:schematron-output>
   </xsl:template>
   <!--SCHEMATRON PATTERNS-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">WIPO ST.96 Conformance Validation</svrl:text>
   <xsl:param name="localFile" select="replace(base-uri(.),'^.*[\\/](.*)','$1')"/>
   <xsl:param name="inSubdirName" select="tokenize(base-uri(), '/')[last()-1]"/>
   <xsl:param name="inComponentSubdirName"
              select="tokenize(replace(base-uri(),'/Document/','/'), '/')[last()-1]"/>
   <xsl:param name="kRegexReleaseDir"
              select="concat('.*/([^/]+)/((',(string-join($namespaces/@subdir,'|')),')/(Document/)?)?$')"/>
   <xsl:param name="kRegexReleaseVersion"
              select="'V(0_[1-9][0-9]*|[1-9]+_(0|[1-9][0-9]*))$'"/>
   <xsl:param name="kRegexLocalFileVersion"
              select="'^[a-zA-Z0-9]+_V([0-9]+)_([0-9]+)\.[a-zA-Z0-9]+$'"/>
   <xsl:param name="kWhereToApproveExceptions" select="'InSchematronRules'"/>
   <xsl:param name="kRepresentationTerms"
              select="('Amount', 'Category', 'Code', 'Date', 'Identifier',               'Indicator', 'Measure', 'Name', 'Number', 'Percent',               'Quantity', 'Rate', 'Text', 'Time', 'DateTime', 'URI')"/>
   <xsl:param name="kNamespaceWIPObase"
              select="'http://www.wipo.int/standards/XMLSchema/ST96/'"/>
   <xsl:param name="kCommonNamespace" select="concat($kNamespaceWIPObase, 'Common')"/>
   <xsl:param name="kPatentNamespace" select="concat($kNamespaceWIPObase, 'Patent')"/>
   <xsl:param name="kTrademarkNamespace"
              select="concat($kNamespaceWIPObase, 'Trademark')"/>
   <xsl:param name="kDesignNamespace" select="concat($kNamespaceWIPObase, 'Design')"/>
   <xsl:param name="kGeographicalIndicationNamespace"
              select="concat($kNamespaceWIPObase, 'GeographicalIndication')"/>
   <xsl:param name="kCopyrightNamespace"
              select="concat($kNamespaceWIPObase, 'Copyright')"/>
   <xsl:param name="kXMLSchemaNamespace" select="'http://www.w3.org/2001/XMLSchema'"/>
   <xsl:param name="kMathMLNamespace" select="'http://www.w3.org/1998/Math/MathML3'"/>
   <xsl:param name="kOASISTableNamespace"
              select="'http://www.oasis-open.org/tables/exchange/1.0'"/>
   <xsl:param name="kIPOCommonNamespace" select="fnx:ipo-ns('common', 'ns')"/>
   <xsl:param name="kIPOPatentNamespace" select="fnx:ipo-ns('patent', 'ns')"/>
   <xsl:param name="kIPOTrademarkNamespace" select="fnx:ipo-ns('trademark', 'ns')"/>
   <xsl:param name="kIPODesignNamespace" select="fnx:ipo-ns('design', 'ns')"/>
   <xsl:param name="kIPOGeographicalIndicationNamespace"
              select="fnx:ipo-ns('geographicalindication', 'ns')"/>
   <xsl:param name="kIPOCopyrightNamespace" select="fnx:ipo-ns('copyright', 'ns')"/>
   <xsl:param name="kIPOCommonNamespacePrefix"
              select="fnx:ipo-ns('common', 'ns-prefix')"/>
   <xsl:param name="prefixTable" select="fnx:buildPrefixTable(/xsd:schema)"/>
   <xsl:param name="approvedAcronyms"
              select="doc('../AcronymsAndAbbreviations.xml'), doc('../AcronymsAndAbbreviationsLocal.xml')"/>
   <xsl:param name="approvedExceptions"
              select="if (doc-available('../ApprovedExceptions.xml')) then doc('../ApprovedExceptions.xml') else false()"/>
   <xsl:param name="definitions" select="fnx:gatherDefinitionsRoot(/xsd:schema, 0)"/>
   <xsl:param name="connectingWords"
              select="doc('../ConnectingWords.xml')/Words/Word"/>
   <xsl:param name="legalReferencePrefixes"
              select="doc('../LegalReferencePrefixes.xml')/Prefixes/Prefix"/>
   <xsl:param name="namespaces"
              select="doc('../BaselineNamespaces.xml')/Namespaces/Namespace"/>
   <xsl:param name="lookupTable" select="fnx:buildLookupTable()"/>
   <xsl:param name="st3Codes" select="doc('../WIPOST3Codes.xml')/Codes/Code"/>
   <xsl:param name="st96Version"
              select="if (doc-available('../st96Version.xml')) then (doc('../st96Version.xml')//*:attribute[@name eq 'st96Version'][1]/@*:fixed) else (collection(concat(replace(translate(base-uri(),'\','/'),'/(Common|Patent|Design|Trademark|Copyright|GeographicalIndication)/.*',''), '?select=*xsd&amp;recurse=yes'))/*:schema[*:attribute[@name eq 'st96Version']][1]/*:attribute[@name eq 'st96Version'][1]/@*:fixed)"/>
   <xsl:param name="ipoVersion"
              select="if (doc-available('../ipoVersion.xml')) then (doc('../ipoVersion.xml')//*:attribute[@name eq 'ipoVersion'][1]/@*:fixed) else (collection(concat(replace(translate(base-uri(),'\','/'),'/(Common|Patent|Design|Trademark|Copyright|GeographicalIndication)/.*',''), '?select=*xsd&amp;recurse=yes'))/*:schema[*:attribute[@name eq 'ipoVersion']][1]/*:attribute[@name eq 'ipoVersion'][1]/@*:fixed)"/>
   <xsl:param name="isFlattened" select="count(/xsd:schema/*[@name]) &gt; 1"/>
   <xsl:param name="kIPONonCommonNamespaces"
              select="($kIPOPatentNamespace,$kIPOTrademarkNamespace,$kIPODesignNamespace,$kIPOGeographicalIndicationNamespace,$kIPOCopyrightNamespace)"/>
   <xsl:param name="kNonCommonNamespaces"
              select="($kPatentNamespace,$kTrademarkNamespace,$kDesignNamespace,$kGeographicalIndicationNamespace,$kCopyrightNamespace)"/>
   <xsl:param name="kAllowedCrossrefNamespaces"
              select="($kTrademarkNamespace,$kGeographicalIndicationNamespace)"/>
   <xsl:param name="targetNamespaceName"
              select="tokenize(/xsd:schema/@targetNamespace,'[/:]')[last()]"/>
   <!--PATTERN SD-63-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">SD-63</svrl:text>
   <!--RULE -->
   <xsl:template match="/xsd:schema/xsd:element" priority="1001" mode="M83">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/xsd:schema/xsd:element"/>
      <xsl:variable name="ipoImplementation"
                    select="@targetNamespace = ($kIPOCommonNamespace,$kIPONonCommonNamespaces)"/>
      <!--ASSERT ERROR-->
      <xsl:choose>
         <xsl:when test="not($ipoImplementation) or ((fnx:is-exception('SD-63','') or $inSubdirName != 'Document' or fnx:has-attribute(.,'ipoVersion','optional') or fnx:has-attribute(.,'ipoVersion','required')) and $ipoImplementation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($ipoImplementation) or ((fnx:is-exception('SD-63','') or $inSubdirName != 'Document' or fnx:has-attribute(.,'ipoVersion','optional') or fnx:has-attribute(.,'ipoVersion','required')) and $ipoImplementation)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="role">ERROR</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
        Root element does not declare the ipoVersion attribute
      </svrl:text>
               <svrl:diagnostic-reference diagnostic="componentName">
                  <xsl:text/>
                  <xsl:value-of select="ancestor-or-self::*/@name[1]"/>
                  <xsl:text/>
               </svrl:diagnostic-reference>
               <svrl:diagnostic-reference diagnostic="namespaceName">
                  <xsl:text/>
                  <xsl:value-of select="$targetNamespaceName"/>
                  <xsl:text/>
               </svrl:diagnostic-reference>
               <svrl:diagnostic-reference diagnostic="SD-63">
</svrl:diagnostic-reference>
               <svrl:diagnostic-reference diagnostic="uri">
                  <xsl:text/>
                  <xsl:value-of select="document-uri(/)"/>
                  <xsl:text/>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT ERROR-->
      <xsl:choose>
         <xsl:when test="not($ipoImplementation) or ((fnx:is-exception('SD-63','') or $inSubdirName != 'Document' or fnx:has-attribute(.,'ipoVersion','optional')) and $ipoImplementation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($ipoImplementation) or ((fnx:is-exception('SD-63','') or $inSubdirName != 'Document' or fnx:has-attribute(.,'ipoVersion','optional')) and $ipoImplementation)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="role">ERROR</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
          Root element does not declare the ipoVersion attribute as optional
      </svrl:text>
               <svrl:diagnostic-reference diagnostic="componentName">
                  <xsl:text/>
                  <xsl:value-of select="ancestor-or-self::*/@name[1]"/>
                  <xsl:text/>
               </svrl:diagnostic-reference>
               <svrl:diagnostic-reference diagnostic="namespaceName">
                  <xsl:text/>
                  <xsl:value-of select="$targetNamespaceName"/>
                  <xsl:text/>
               </svrl:diagnostic-reference>
               <svrl:diagnostic-reference diagnostic="SD-63">
</svrl:diagnostic-reference>
               <svrl:diagnostic-reference diagnostic="uri">
                  <xsl:text/>
                  <xsl:value-of select="document-uri(/)"/>
                  <xsl:text/>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT ERROR-->
      <xsl:choose>
         <xsl:when test="not($ipoImplementation) or ((fnx:is-exception('SD-63','')                     or $inSubdirName != 'Document' or not(fnx:has-attribute(.,'ipoVersion','optional'))                     or fnx:has-fixed-attribute(., 'ipoVersion', 'optional', concat('^(',string-join($st3Codes,'|'),')_',$kRegexReleaseVersion))) and $ipoImplementation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($ipoImplementation) or ((fnx:is-exception('SD-63','') or $inSubdirName != 'Document' or not(fnx:has-attribute(.,'ipoVersion','optional')) or fnx:has-fixed-attribute(., 'ipoVersion', 'optional', concat('^(',string-join($st3Codes,'|'),')_',$kRegexReleaseVersion))) and $ipoImplementation)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="role">ERROR</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
        Root element does not declare optional ipoVersion attribute
        with a fixed value of the form {ST3CODE}_V{n}_{m}.
      </svrl:text>
               <svrl:diagnostic-reference diagnostic="componentName">
                  <xsl:text/>
                  <xsl:value-of select="ancestor-or-self::*/@name[1]"/>
                  <xsl:text/>
               </svrl:diagnostic-reference>
               <svrl:diagnostic-reference diagnostic="namespaceName">
                  <xsl:text/>
                  <xsl:value-of select="$targetNamespaceName"/>
                  <xsl:text/>
               </svrl:diagnostic-reference>
               <svrl:diagnostic-reference diagnostic="SD-63">
</svrl:diagnostic-reference>
               <svrl:diagnostic-reference diagnostic="uri">
                  <xsl:text/>
                  <xsl:value-of select="document-uri(/)"/>
                  <xsl:text/>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M83"/>
   </xsl:template>
   <!--RULE -->
   <xsl:template match="xsd:attribute[@fixed][@name = 'ipoVersion']"
                 priority="1000"
                 mode="M83">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="xsd:attribute[@fixed][@name = 'ipoVersion']"/>
      <xsl:variable name="ipoImplementation"
                    select="@targetNamespace = ($kIPOCommonNamespace,$kIPONonCommonNamespaces)"/>
      <!--ASSERT ERROR-->
      <xsl:choose>
         <xsl:when test="($ipoImplementation and fnx:is-exception('SD-63',@name)                     or not(matches(@fixed, '^[A-Z][A-Z]_V[0-9]+_[0-9]+$'))                     or matches(@fixed,concat('^(',string-join($st3Codes,'|'),')_',$kRegexReleaseVersion))) or not($ipoImplementation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="($ipoImplementation and fnx:is-exception('SD-63',@name) or not(matches(@fixed, '^[A-Z][A-Z]_V[0-9]+_[0-9]+$')) or matches(@fixed,concat('^(',string-join($st3Codes,'|'),')_',$kRegexReleaseVersion))) or not($ipoImplementation)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="role">ERROR</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
        @ipoVersion=<xsl:text/>
                  <xsl:value-of select="@fixed"/>
                  <xsl:text/> is fixed but does not start with a valid ST.3 code.
      </svrl:text>
               <svrl:diagnostic-reference diagnostic="componentName">
                  <xsl:text/>
                  <xsl:value-of select="ancestor-or-self::*/@name[1]"/>
                  <xsl:text/>
               </svrl:diagnostic-reference>
               <svrl:diagnostic-reference diagnostic="namespaceName">
                  <xsl:text/>
                  <xsl:value-of select="$targetNamespaceName"/>
                  <xsl:text/>
               </svrl:diagnostic-reference>
               <svrl:diagnostic-reference diagnostic="SD-63">
</svrl:diagnostic-reference>
               <svrl:diagnostic-reference diagnostic="uri">
                  <xsl:text/>
                  <xsl:value-of select="document-uri(/)"/>
                  <xsl:text/>
               </svrl:diagnostic-reference>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M83"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M83"/>
   <xsl:template match="@*|node()" priority="-2" mode="M83">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M83"/>
   </xsl:template>
</xsl:stylesheet>
