<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:fnx="http://www.example.com/fnx"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
   <xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>
   <!--PHASES-->
   <!--PROLOG-->
   <xsl:output method="xml"
               omit-xml-declaration="no"
               standalone="yes"
               indent="yes"/>
   <!--XSD TYPES FOR XSLT2-->
   <!--KEYS AND FUNCTIONS-->
   <!--DEFAULT RULES-->
   <!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-2-->
   <!--This mode can be used to generate prefixed XPath for humans-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
   <!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: GENERATE-ID-FROM-PATH -->
   <xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>
   <!--MODE: GENERATE-ID-2 -->
   <xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters-->
   <xsl:template match="text()" priority="-1"/>
   <!--SCHEMA SETUP-->
   <xsl:template match="/">
      <svrl:schematron-output title="ST.96 Conformance Checker - Test Suite Results"
                              schemaVersion="1.0">
         <xsl:comment>
            <xsl:value-of select="$archiveDirParameter"/>   
		 <xsl:value-of select="$archiveNameParameter"/>  
		 <xsl:value-of select="$fileNameParameter"/>  
		 <xsl:value-of select="$fileDirParameter"/>
         </xsl:comment>
         <svrl:ns-prefix-in-attribute-values uri="http://purl.oclc.org/dsdl/svrl" prefix="svrl"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.example.com/fnx" prefix="fnx"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="name">SD-03</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M4"/>
      </svrl:schematron-output>
   </xsl:template>
   <!--SCHEMATRON PATTERNS-->
   <svrl:text>ST.96 Conformance Checker - Test Suite Results</svrl:text>
   <xsl:include xmlns="http://purl.oclc.org/dsdl/schematron" href="test_common.xsl"/>
   <!--PATTERN SD-03-->
   <svrl:text>SD-03</svrl:text>
   <!--RULE -->
   <xsl:template match="svrl:schematron-output" priority="1000" mode="M4">
      <svrl:fired-rule context="svrl:schematron-output" role="ERROR"/>
      <xsl:variable name="inFileName" select="tokenize(base-uri(), '/')[last()]"/>
      <xsl:variable name="failmsg1b"
                    select="fnx:expect-infile(                                    'XSDs in the http://www.wipo.int/standards/XMLSchema/ST96/Patent namespace may not refer to XSDs in the following namespace(s): http://www.wipo.int/standards/XMLSchema/ST96/Trademark, http://www.wipo.int/standards/XMLSchema/ST96/Design.',                                    '1b.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg1c"
                    select="fnx:expect-infile(                                    'XSDs in the http://www.wipo.int/standards/XMLSchema/ST96/Patent namespace may not refer to XSDs in the following namespace(s): urn:us:gov:doc:uspto:trademark, urn:us:gov:doc:uspto:design, urn:us:gov:doc:uspto:corporate, urn:us:gov:doc:uspto:dissemination, urn:us:gov:doc:uspto:legal.',                                    '1c.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg2b"
                    select="fnx:expect-infile(                                    'XSDs in the http://www.wipo.int/standards/XMLSchema/ST96/Trademark namespace may not refer to XSDs in the following namespace(s): http://www.wipo.int/standards/XMLSchema/ST96/Patent, http://www.wipo.int/standards/XMLSchema/ST96/Design.',                                    '2b.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg2c"
                    select="fnx:expect-infile(                                    'XSDs in the http://www.wipo.int/standards/XMLSchema/ST96/Trademark namespace may not refer to XSDs in the following namespace(s): urn:us:gov:doc:uspto:patent, urn:us:gov:doc:uspto:design, urn:us:gov:doc:uspto:corporate, urn:us:gov:doc:uspto:dissemination, urn:us:gov:doc:uspto:legal.',                                    '2c.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg3b"
                    select="fnx:expect-infile(                                    'XSDs in the http://www.wipo.int/standards/XMLSchema/ST96/Design namespace may not refer to XSDs in the following namespace(s): http://www.wipo.int/standards/XMLSchema/ST96/Trademark, http://www.wipo.int/standards/XMLSchema/ST96/Patent.',                                    '3b.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg3c"
                    select="fnx:expect-infile(                                    'XSDs in the http://www.wipo.int/standards/XMLSchema/ST96/Design namespace may not refer to XSDs in the following namespace(s):         urn:us:gov:doc:uspto:trademark, urn:us:gov:doc:uspto:patent, urn:us:gov:doc:uspto:corporate, urn:us:gov:doc:uspto:dissemination, urn:us:gov:doc:uspto:legal.',                                    '3c.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg4b"
                    select="fnx:expect-infile(                                    'XSDs in the urn:us:gov:doc:uspto:patent namespace may not refer to XSDs in the following namespace(s): http://www.wipo.int/standards/XMLSchema/ST96/Trademark, http://www.wipo.int/standards/XMLSchema/ST96/Design.',                                    '4b.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg4c"
                    select="fnx:expect-infile(                                    'XSDs in the urn:us:gov:doc:uspto:patent namespace may not refer to XSDs in the following namespace(s): urn:us:gov:doc:uspto:trademark, urn:us:gov:doc:uspto:design, urn:us:gov:doc:uspto:corporate, urn:us:gov:doc:uspto:dissemination, urn:us:gov:doc:uspto:legal.',                                    '4c.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg5b"
                    select="fnx:expect-infile(                                    'XSDs in the urn:us:gov:doc:uspto:trademark namespace may not refer to XSDs in the following namespace(s): http://www.wipo.int/standards/XMLSchema/ST96/Patent, http://www.wipo.int/standards/XMLSchema/ST96/Design.',                                    '5b.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg5c"
                    select="fnx:expect-infile(                                    'XSDs in the urn:us:gov:doc:uspto:trademark namespace may not refer to XSDs in the following namespace(s): urn:us:gov:doc:uspto:patent, urn:us:gov:doc:uspto:design, urn:us:gov:doc:uspto:corporate, urn:us:gov:doc:uspto:dissemination, urn:us:gov:doc:uspto:legal.',                                    '5c.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg6b"
                    select="fnx:expect-infile(                                    'XSDs in the urn:us:gov:doc:uspto:design namespace may not refer to XSDs in the following namespace(s): http://www.wipo.int/standards/XMLSchema/ST96/Trademark, http://www.wipo.int/standards/XMLSchema/ST96/Patent.',                                    '6b.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg6c"
                    select="fnx:expect-infile(                                    'XSDs in the urn:us:gov:doc:uspto:design namespace may not refer to XSDs in the following namespace(s): urn:us:gov:doc:uspto:trademark, urn:us:gov:doc:uspto:patent, urn:us:gov:doc:uspto:corporate, urn:us:gov:doc:uspto:dissemination, urn:us:gov:doc:uspto:legal.',                                    '6c.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg7b"
                    select="fnx:expect-infile(                                    'XSDs in the urn:us:gov:doc:uspto:corporate namespace may not refer to XSDs in the following namespace(s): http://www.wipo.int/standards/XMLSchema/ST96/Patent, http://www.wipo.int/standards/XMLSchema/ST96/Trademark, http://www.wipo.int/standards/XMLSchema/ST96/Design.',                                    '7b.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg7c"
                    select="fnx:expect-infile(                                    'XSDs in the urn:us:gov:doc:uspto:corporate namespace may not refer to XSDs in the following namespace(s): urn:us:gov:doc:uspto:patent, urn:us:gov:doc:uspto:trademark, urn:us:gov:doc:uspto:design, urn:us:gov:doc:uspto:dissemination, urn:us:gov:doc:uspto:legal.',                                    '7c.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg8b"
                    select="fnx:expect-infile(                                    'XSDs in the urn:us:gov:doc:uspto:dissemination namespace may not refer to XSDs in the following namespace(s): http://www.wipo.int/standards/XMLSchema/ST96/Patent, http://www.wipo.int/standards/XMLSchema/ST96/Trademark, http://www.wipo.int/standards/XMLSchema/ST96/Design.',                                    '8b.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg8c"
                    select="fnx:expect-infile(                                    'XSDs in the urn:us:gov:doc:uspto:dissemination namespace may not refer to XSDs in the following namespace(s): urn:us:gov:doc:uspto:patent, urn:us:gov:doc:uspto:trademark, urn:us:gov:doc:uspto:design, urn:us:gov:doc:uspto:corporate, urn:us:gov:doc:uspto:legal.',                                    '8c.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg9b"
                    select="fnx:expect-infile(                                    'XSDs in the urn:us:gov:doc:uspto:legal namespace may not refer to XSDs in the following namespace(s): http://www.wipo.int/standards/XMLSchema/ST96/Patent, http://www.wipo.int/standards/XMLSchema/ST96/Trademark, http://www.wipo.int/standards/XMLSchema/ST96/Design.',                                    '9b.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg9c"
                    select="fnx:expect-infile(                                    'XSDs in the urn:us:gov:doc:uspto:legal namespace may not refer to XSDs in the following namespace(s): urn:us:gov:doc:uspto:patent, urn:us:gov:doc:uspto:trademark, urn:us:gov:doc:uspto:design, urn:us:gov:doc:uspto:corporate, urn:us:gov:doc:uspto:dissemination.',                                    '9c.svrl', $inFileName, /)"/>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(0, '1.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(0, '1.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(0, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(0, '2.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(0, '2.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(0, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(0, '3.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(0, '3.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(0, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(0, '4.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(0, '4.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(0, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(0, '5.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(0, '5.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(0, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(0, '6.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(0, '6.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(0, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(0, '7.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(0, '7.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(0, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(0, '8.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(0, '8.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(0, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(0, '9.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(0, '9.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(0, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(1, '1b.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(1, '1b.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(1, '2b.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(1, '2b.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(1, '3b.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(1, '3b.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(fnx:ipo-has('trademark', 'ns-prefix', 'ustmk'))                     or not(fnx:ipo-has('design', 'ns-prefix', 'usdgn'))                     or fnx:failed-assert-count-is-infile(1, '4b.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(fnx:ipo-has('trademark', 'ns-prefix', 'ustmk')) or not(fnx:ipo-has('design', 'ns-prefix', 'usdgn')) or fnx:failed-assert-count-is-infile(1, '4b.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(fnx:ipo-has('patent', 'ns-prefix', 'uspat'))                     or not(fnx:ipo-has('design', 'ns-prefix', 'usdgn'))                     or fnx:failed-assert-count-is-infile(1, '5b.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(fnx:ipo-has('patent', 'ns-prefix', 'uspat')) or not(fnx:ipo-has('design', 'ns-prefix', 'usdgn')) or fnx:failed-assert-count-is-infile(1, '5b.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(fnx:ipo-has('trademark', 'ns-prefix', 'ustmk'))                     or not(fnx:ipo-has('patent', 'ns-prefix', 'uspat'))                     or fnx:failed-assert-count-is-infile(1, '6b.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(fnx:ipo-has('trademark', 'ns-prefix', 'ustmk')) or not(fnx:ipo-has('patent', 'ns-prefix', 'uspat')) or fnx:failed-assert-count-is-infile(1, '6b.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(1, '7b.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(1, '7b.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(1, '8b.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(1, '8b.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(1, '9b.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(1, '9b.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(fnx:ipo-has('trademark', 'ns-prefix', 'ustmk'))                     or not(fnx:ipo-has('design', 'ns-prefix', 'usdgn'))                     or fnx:failed-assert-count-is-infile(1, '1c.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(fnx:ipo-has('trademark', 'ns-prefix', 'ustmk')) or not(fnx:ipo-has('design', 'ns-prefix', 'usdgn')) or fnx:failed-assert-count-is-infile(1, '1c.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(fnx:ipo-has('patent', 'ns-prefix', 'uspat'))                     or not(fnx:ipo-has('design', 'ns-prefix', 'usdgn'))                     or fnx:failed-assert-count-is-infile(1, '2c.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(fnx:ipo-has('patent', 'ns-prefix', 'uspat')) or not(fnx:ipo-has('design', 'ns-prefix', 'usdgn')) or fnx:failed-assert-count-is-infile(1, '2c.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(fnx:ipo-has('trademark', 'ns-prefix', 'ustmk'))                     or not(fnx:ipo-has('patent', 'ns-prefix', 'uspat'))                     or fnx:failed-assert-count-is-infile(1, '3c.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(fnx:ipo-has('trademark', 'ns-prefix', 'ustmk')) or not(fnx:ipo-has('patent', 'ns-prefix', 'uspat')) or fnx:failed-assert-count-is-infile(1, '3c.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(fnx:ipo-has('trademark', 'ns-prefix', 'ustmk'))                     or not(fnx:ipo-has('design', 'ns-prefix', 'usdgn'))                     or fnx:failed-assert-count-is-infile(1, '4c.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(fnx:ipo-has('trademark', 'ns-prefix', 'ustmk')) or not(fnx:ipo-has('design', 'ns-prefix', 'usdgn')) or fnx:failed-assert-count-is-infile(1, '4c.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(fnx:ipo-has('patent', 'ns-prefix', 'uspat'))                     or not(fnx:ipo-has('design', 'ns-prefix', 'usdgn'))                     or fnx:failed-assert-count-is-infile(1, '5c.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(fnx:ipo-has('patent', 'ns-prefix', 'uspat')) or not(fnx:ipo-has('design', 'ns-prefix', 'usdgn')) or fnx:failed-assert-count-is-infile(1, '5c.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="not(fnx:ipo-has('trademark', 'ns-prefix', 'ustmk'))                     or not(fnx:ipo-has('patent', 'ns-prefix', 'uspat'))                     or fnx:failed-assert-count-is-infile(1, '6c.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(fnx:ipo-has('trademark', 'ns-prefix', 'ustmk')) or not(fnx:ipo-has('patent', 'ns-prefix', 'uspat')) or fnx:failed-assert-count-is-infile(1, '6c.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(1, '7c.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(1, '7c.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(1, '8c.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(1, '8c.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(1, '9c.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(1, '9c.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg1b, '1b.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg1b, '1b.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg1b"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg1c, '1c.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg1c, '1c.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg1c"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg2b, '2b.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg2b, '2b.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg2b"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg2c, '2c.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg2c, '2c.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg2c"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg3b, '3b.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg3b, '3b.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg3b"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg3c, '3c.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg3c, '3c.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg3c"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg4b, '4b.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg4b, '4b.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg4b"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg4c, '4c.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg4c, '4c.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg4c"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg5b, '5b.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg5b, '5b.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg5b"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg5c, '5c.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg5c, '5c.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg5c"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg6b, '6b.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg6b, '6b.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg6b"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg6c, '6c.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg6c, '6c.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg6c"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg7b, '7b.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg7b, '7b.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg7b"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg7c, '7c.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg7c, '7c.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg7c"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg8b, '8b.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg8b, '8b.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg8b"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg8c, '8c.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg8c, '8c.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg8c"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg9b, '9b.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg9b, '9b.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg9b"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg9c, '9c.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg9c, '9c.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg9c"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M4"/>
   <xsl:template match="@*|node()" priority="-2" mode="M4">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>
</xsl:stylesheet>
