<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:fnx="http://www.example.com/fnx"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
   <xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>
   <!--PHASES-->
   <!--PROLOG-->
   <xsl:output method="xml"
               omit-xml-declaration="no"
               standalone="yes"
               indent="yes"/>
   <!--XSD TYPES FOR XSLT2-->
   <!--KEYS AND FUNCTIONS-->
   <!--DEFAULT RULES-->
   <!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-2-->
   <!--This mode can be used to generate prefixed XPath for humans-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
   <!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: GENERATE-ID-FROM-PATH -->
   <xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>
   <!--MODE: GENERATE-ID-2 -->
   <xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters-->
   <xsl:template match="text()" priority="-1"/>
   <!--SCHEMA SETUP-->
   <xsl:template match="/">
      <svrl:schematron-output title="ST.96 Conformance Checker - Test Suite Results"
                              schemaVersion="1.0">
         <xsl:comment>
            <xsl:value-of select="$archiveDirParameter"/>   
		 <xsl:value-of select="$archiveNameParameter"/>  
		 <xsl:value-of select="$fileNameParameter"/>  
		 <xsl:value-of select="$fileDirParameter"/>
         </xsl:comment>
         <svrl:ns-prefix-in-attribute-values uri="http://purl.oclc.org/dsdl/svrl" prefix="svrl"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.example.com/fnx" prefix="fnx"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="name">SD-64</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M4"/>
      </svrl:schematron-output>
   </xsl:template>
   <!--SCHEMATRON PATTERNS-->
   <svrl:text>ST.96 Conformance Checker - Test Suite Results</svrl:text>
   <xsl:include xmlns="http://purl.oclc.org/dsdl/schematron" href="test_common.xsl"/>
   <!--PATTERN SD-64-->
   <svrl:text>SD-64</svrl:text>
   <!--RULE -->
   <xsl:template match="svrl:schematron-output" priority="1000" mode="M4">
      <svrl:fired-rule context="svrl:schematron-output" role="ERROR"/>
      <xsl:variable name="inFileName" select="tokenize(base-uri(), '/')[last()]"/>
      <xsl:variable name="expected2"
                    select="'No schema release folder was found with the required format ST96/V&lt;MajorVersionNum&gt;_&lt;MinorVersionNum&gt; for Document XSD named badA_V2_0.xsd.'"/>
      <xsl:variable name="expected5"
                    select="'No schema release folder was found with the required format ST96/V&lt;MajorVersionNum&gt;_&lt;MinorVersionNum&gt; for Document XSD named bad_V2_0.xsd.'"/>
      <xsl:variable name="expected6"
                    select="'The flattened schema file name badD.xsd does not contain version information in the required format &lt;ComponentName&gt;[_V&lt;MajorVersionNum&gt;_&lt;MinorVersionNum&gt;].&lt;FileExtension&gt;'"/>
      <xsl:variable name="expected8"
                    select="'The Document schema file name badC.xsd does not contain version information in the required format &lt;ComponentName&gt;[_V&lt;MajorVersionNum&gt;_&lt;MinorVersionNum&gt;].&lt;FileExtension&gt;'"/>
      <xsl:variable name="expected9"
                    select="'The Document schema file name badC_V1_0.xsd has a major version number (1) that does not match the release major version number (2).'"/>
      <xsl:variable name="expected10"
                    select="'The Document schema file name badC_V2.0.xsd does not contain version information in the required format &lt;ComponentName&gt;[_V&lt;MajorVersionNum&gt;_&lt;MinorVersionNum&gt;].&lt;FileExtension&gt;'"/>
      <xsl:variable name="expected11"
                    select="'The Document schema file name badC_v2_0.xsd does not contain version information in the required format &lt;ComponentName&gt;[_V&lt;MajorVersionNum&gt;_&lt;MinorVersionNum&gt;].&lt;FileExtension&gt;'"/>
      <xsl:variable name="expected12"
                    select="'The Document schema file name badC_V2_0_0.xsd does not contain version information in the required format &lt;ComponentName&gt;[_V&lt;MajorVersionNum&gt;_&lt;MinorVersionNum&gt;].&lt;FileExtension&gt;'"/>
      <xsl:variable name="expected13"
                    select="'The Document schema file name badC_V2_1.xsd has a minor version number (1) that does not match the release minor version number (0).'"/>
      <xsl:variable name="failmsg2"
                    select="fnx:expect-infile(                                   $expected2,                                   'badA_V2_0.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg5"
                    select="fnx:expect-infile(                                   $expected5,                                   'bad_V2_0.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg6"
                    select="fnx:expect-infile(                                   $expected6,                                   'badD.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg8"
                    select="fnx:expect-infile(                                   $expected8,                                   'badC.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg9"
                    select="fnx:expect-infile(                                    $expected9,                                    'badC_V1_0.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg10"
                    select="fnx:expect-infile(                                    $expected10,                                    'badC_V2.0.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg11"
                    select="fnx:expect-infile(                                    $expected11,                                    'badC_v2_0.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg12"
                    select="fnx:expect-infile(                                    $expected12,                                    'badC_V2_0_0.svrl', $inFileName, /)"/>
      <xsl:variable name="failmsg13"
                    select="fnx:expect-infile(                                    $expected13,                                    'badC_V2_1.svrl', $inFileName, /)"/>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(0, 'goodB.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(0, 'goodB.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(0, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(1, 'badA_V2_0.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(1, 'badA_V2_0.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(0, 'goodA.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(0, 'goodA.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(0, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(0, 'good.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(0, 'good.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(0, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(1, 'bad_V2_0.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(1, 'bad_V2_0.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(1, 'badD.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(1, 'badD.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(0, 'goodD_V2_0.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(0, 'goodD_V2_0.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(0, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(1, 'badC.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(1, 'badC.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(1, 'badC_V1_0.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(1, 'badC_V1_0.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(1, 'badC_V2.0.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(1, 'badC_V2.0.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(1, 'badC_v2_0.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(1, 'badC_v2_0.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(1, 'badC_V2_0_0.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(1, 'badC_V2_0_0.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(1, 'badC_V2_1.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(1, 'badC_V2_1.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(1, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:failed-assert-count-is-infile(0, 'goodC_V2_0.svrl', $inFileName, .)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:failed-assert-count-is-infile(0, 'goodC_V2_0.svrl', $inFileName, .)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:value-of xmlns="http://purl.oclc.org/dsdl/schematron"
                                select="fnx:wrong-error-count-message(0, .)"/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg2, 'badA_V2_0.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg2, 'badA_V2_0.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg2"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg5, 'bad_V2_0.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg5, 'bad_V2_0.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg5"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg6, 'badD.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg6, 'badD.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg6"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg8, 'badC.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg8, 'badC.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg8"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg9, 'badC_V1_0.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg9, 'badC_V1_0.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg9"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg10, 'badC_V2.0.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg10, 'badC_V2.0.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg10"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg11, 'badC_v2_0.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg11, 'badC_v2_0.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg11"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg12, 'badC_V2_0_0.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg12, 'badC_V2_0_0.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg12"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fnx:no-fail-infile($failmsg13, 'badC_V2_1.svrl', $inFileName)"/>
         <xsl:otherwise>
            <svrl:failed-assert test="fnx:no-fail-infile($failmsg13, 'badC_V2_1.svrl', $inFileName)">
               <xsl:attribute name="flag">AUTO</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="$failmsg13"/>
                  <xsl:text/>
               </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M4"/>
   <xsl:template match="@*|node()" priority="-2" mode="M4">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>
</xsl:stylesheet>
